summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorJordan K. Hubbard <jkh@FreeBSD.org>1996-06-05 02:59:00 +0000
committerJordan K. Hubbard <jkh@FreeBSD.org>1996-06-05 02:59:00 +0000
commit78e55a1f29558e8be54566ead1e7be8ab9d45273 (patch)
tree65fd45fa55d0cd3888b40a4f41dd3383616dfd74 /include
parent885f2f31b4599f4bc7468278c783c1c30f1f86ed (diff)
Notes
Diffstat (limited to 'include')
-rw-r--r--include/Makefile12
-rw-r--r--include/arpa/nameser.h5
-rw-r--r--include/arpa/telnet.h2
-rw-r--r--include/ctype.h56
-rw-r--r--include/db.h6
-rw-r--r--include/link.h8
-rw-r--r--include/mpool.h110
-rw-r--r--include/ndbm.h2
-rw-r--r--include/netdb.h6
-rw-r--r--include/protocols/routed.h109
-rw-r--r--include/resolv.h7
-rw-r--r--include/rpc/auth.h14
-rw-r--r--include/rpc/auth_unix.h4
-rw-r--r--include/rpc/clnt.h8
-rw-r--r--include/rpc/pmap_clnt.h4
-rw-r--r--include/rpc/pmap_prot.h4
-rw-r--r--include/rpc/pmap_rmt.h4
-rw-r--r--include/rpc/rpc.h4
-rw-r--r--include/rpc/rpc_msg.h4
-rw-r--r--include/rpc/svc.h6
-rw-r--r--include/rpc/svc_auth.h4
-rw-r--r--include/rpc/types.h4
-rw-r--r--include/rpc/xdr.h10
-rw-r--r--include/rpcsvc/Makefile2
-rw-r--r--include/rpcsvc/bootparam_prot.x2
-rw-r--r--include/rpcsvc/yp.x97
-rw-r--r--include/rpcsvc/yp_prot.h8
-rw-r--r--include/runetype.h23
-rw-r--r--include/signal.h18
-rw-r--r--include/stddef.h10
-rw-r--r--include/stdio.h10
-rw-r--r--include/stdlib.h10
-rw-r--r--include/strhash.h2
-rw-r--r--include/time.h7
-rw-r--r--include/unistd.h2
-rw-r--r--include/vis.h10
36 files changed, 228 insertions, 366 deletions
diff --git a/include/Makefile b/include/Makefile
index 9c819ff712ba..227127e34681 100644
--- a/include/Makefile
+++ b/include/Makefile
@@ -1,5 +1,5 @@
# From: @(#)Makefile 8.2 (Berkeley) 1/4/94
-# $Id: Makefile,v 1.35 1996/02/14 15:17:53 wollman Exp $
+# $Id: Makefile,v 1.25.4.2 1995/08/31 21:30:59 davidg Exp $
#
# Doing a make install builds /usr/include
#
@@ -10,13 +10,14 @@ all depend lint tags:
CLEANFILES=version vers.c
SUBDIR= rpcsvc
+# XXX MISSING: mp.h
FILES= a.out.h ar.h assert.h bitstring.h ctype.h db.h dirent.h disktab.h \
err.h f2c.h fnmatch.h fstab.h fts.h glob.h grp.h strhash.h histedit.h \
kvm.h limits.h link.h locale.h malloc.h memory.h mpool.h ndbm.h \
- netdb.h nl_types.h nlist.h paths.h pthread.h pwd.h ranlib.h regex.h \
- regexp.h resolv.h rune.h runetype.h setjmp.h sgtty.h signal.h \
+ netdb.h nl_types.h nlist.h paths.h pwd.h ranlib.h regex.h regexp.h \
+ resolv.h rune.h runetype.h setjmp.h sgtty.h signal.h \
stab.h stddef.h stdio.h stdlib.h string.h strings.h struct.h \
- sysexits.h tar.h time.h timers.h ttyent.h unistd.h utime.h \
+ sysexits.h tar.h time.h ttyent.h unistd.h utime.h \
utmp.h vis.h
.if defined(WANT_CSRG_LIBM)
FILES+= math.h
@@ -26,7 +27,7 @@ MFILES= float.h floatingpoint.h stdarg.h varargs.h
LFILES= errno.h fcntl.h syslog.h termios.h
DIRS= arpa protocols rpc
-LDIRS= net netinet netipx nfs sys vm #netccitt netiso netns
+LDIRS= net netccitt netinet netiso netns nfs sys vm
LUDIR= ufs
UDIRS= ufs/ffs ufs/lfs ufs/mfs ufs/ufs
@@ -92,7 +93,6 @@ copies:
rm -rf ${DESTDIR}/usr/include/${LUDIR}
mkdir ${DESTDIR}/usr/include/${LUDIR}
chown ${BINOWN}.${BINGRP} ${DESTDIR}/usr/include/${LUDIR}
- chmod 755 ${DESTDIR}/usr/include/${LUDIR}
@-for i in ${LDIRS} ${UDIRS}; do \
${ECHO} ${SHARED} $$i; \
rm -rf ${DESTDIR}/usr/include/$$i; \
diff --git a/include/arpa/nameser.h b/include/arpa/nameser.h
index a6692269a45b..403530401d8a 100644
--- a/include/arpa/nameser.h
+++ b/include/arpa/nameser.h
@@ -53,7 +53,6 @@
*
* @(#)nameser.h 8.2 (Berkeley) 2/16/94
* From Id: nameser.h,v 4.9.1.15 1994/07/19 22:51:24 vixie Exp
- * $Id: nameser.h,v 1.7 1996/01/30 23:31:16 mpp Exp $
*/
#ifndef _ARPA_NAMESER_H_
@@ -202,7 +201,7 @@ typedef struct {
/* fields in third byte */
unsigned qr: 1; /* response flag */
unsigned opcode: 4; /* purpose of message */
- unsigned aa: 1; /* authoritative answer */
+ unsigned aa: 1; /* authoritive answer */
unsigned tc: 1; /* truncated message */
unsigned rd: 1; /* recursion desired */
/* fields in fourth byte */
@@ -214,7 +213,7 @@ typedef struct {
/* fields in third byte */
unsigned rd :1; /* recursion desired */
unsigned tc :1; /* truncated message */
- unsigned aa :1; /* authoritative answer */
+ unsigned aa :1; /* authoritive answer */
unsigned opcode :4; /* purpose of message */
unsigned qr :1; /* response flag */
/* fields in fourth byte */
diff --git a/include/arpa/telnet.h b/include/arpa/telnet.h
index 89e5c484a4f8..28f52d8b1dbc 100644
--- a/include/arpa/telnet.h
+++ b/include/arpa/telnet.h
@@ -200,7 +200,7 @@ char *telopts[NTELOPTS+1] = {
#define NSLC 18
/*
- * For backwards compatibility, we define SLC_NAMES to be the
+ * For backwards compatability, we define SLC_NAMES to be the
* list of names if SLC_NAMES is not defined.
*/
#define SLC_NAMELIST "0", "SYNCH", "BRK", "IP", "AO", "AYT", "EOR", \
diff --git a/include/db.h b/include/db.h
index cd907c3abe78..abf4ddd8cc15 100644
--- a/include/db.h
+++ b/include/db.h
@@ -1,5 +1,5 @@
/*-
- * Copyright (c) 1990, 1993, 1994
+ * Copyright (c) 1990, 1993
* The Regents of the University of California. All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
@@ -30,7 +30,7 @@
* OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
* SUCH DAMAGE.
*
- * @(#)db.h 8.7 (Berkeley) 6/16/94
+ * @(#)db.h 8.4 (Berkeley) 2/21/94
*/
#ifndef _DB_H_
@@ -152,7 +152,7 @@ typedef struct {
int lorder; /* byte order */
size_t reclen; /* record length (fixed-length records) */
u_char bval; /* delimiting byte (variable-length records */
- char *bfname; /* btree file name */
+ char *bfname; /* btree file name */
} RECNOINFO;
#ifdef __DBINTERFACE_PRIVATE
diff --git a/include/link.h b/include/link.h
index e527ab3d6c45..c71a1fcbd539 100644
--- a/include/link.h
+++ b/include/link.h
@@ -14,7 +14,7 @@
* must display the following acknowledgement:
* This product includes software developed by Paul Kranenburg.
* 4. The name of the author may not be used to endorse or promote products
- * derived from this software without specific prior written permission
+ * derived from this software withough specific prior written permission
*
* THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
* IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
@@ -27,7 +27,7 @@
* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
* THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*
- * $Id: link.h,v 1.6 1996/01/30 23:30:20 mpp Exp $
+ * $Id: link.h,v 1.4.4.1 1995/08/25 07:08:07 davidg Exp $
*/
/*
@@ -42,7 +42,7 @@
#define _LINK_H_
/*
- * A `Shared Object Descriptor' describes a shared object that is needed
+ * A `Shared Object Descriptor' descibes a shared object that is needed
* to complete the link edit process of the object containing it.
* A list of such objects (chained through `sod_next') is pointed at
* by `sdt_sods' in the section_dispatch_table structure.
@@ -237,7 +237,7 @@ struct _dynamic {
*/
struct crt_ldso {
int crt_ba; /* Base address of ld.so */
- int crt_dzfd; /* "/dev/zero" file descriptor (SunOS) */
+ int crt_dzfd; /* "/dev/zero" file decriptor (SunOS) */
int crt_ldfd; /* ld.so file descriptor */
struct _dynamic *crt_dp; /* Main's __DYNAMIC */
char **crt_ep; /* environment strings */
diff --git a/include/ndbm.h b/include/ndbm.h
index 8d50be8655bf..a545bca1326e 100644
--- a/include/ndbm.h
+++ b/include/ndbm.h
@@ -49,7 +49,7 @@
#define DBM_REPLACE 1
/*
- * The db(3) support for ndbm always appends this suffix to the
+ * The db(3) support for ndbm(3) always appends this suffix to the
* file name to avoid overwriting the user's original database.
*/
#define DBM_SUFFIX ".db"
diff --git a/include/netdb.h b/include/netdb.h
index 1b1290b86901..4ea2f630342d 100644
--- a/include/netdb.h
+++ b/include/netdb.h
@@ -31,7 +31,7 @@
* SUCH DAMAGE.
*
* @(#)netdb.h 8.1 (Berkeley) 6/2/93
- * $Id: netdb.h,v 1.4 1996/01/30 23:30:30 mpp Exp $
+ * $Id: netdb.h,v 1.2.4.1 1995/08/30 04:06:24 davidg Exp $
* -
* Portions Copyright (c) 1993 by Digital Equipment Corporation.
*
@@ -76,7 +76,7 @@ struct hostent {
int h_addrtype; /* host address type */
int h_length; /* length of address */
char **h_addr_list; /* list of addresses from name server */
-#define h_addr h_addr_list[0] /* address, for backward compatibility */
+#define h_addr h_addr_list[0] /* address, for backward compatiblity */
};
/*
@@ -111,7 +111,7 @@ struct protoent {
#define NETDB_INTERNAL -1 /* see errno */
#define NETDB_SUCCESS 0 /* no problem */
#define HOST_NOT_FOUND 1 /* Authoritative Answer Host not found */
-#define TRY_AGAIN 2 /* Non-Authoritative Host not found, or SERVERFAIL */
+#define TRY_AGAIN 2 /* Non-Authoritive Host not found, or SERVERFAIL */
#define NO_RECOVERY 3 /* Non recoverable errors, FORMERR, REFUSED, NOTIMP */
#define NO_DATA 4 /* Valid name, no data record of requested type */
#define NO_ADDRESS NO_DATA /* no address, look for MX record */
diff --git a/include/protocols/routed.h b/include/protocols/routed.h
index c2b8327172a0..4dd83bd0bc9c 100644
--- a/include/protocols/routed.h
+++ b/include/protocols/routed.h
@@ -33,12 +33,8 @@
* @(#)routed.h 8.1 (Berkeley) 6/2/93
*/
-#ifndef _ROUTED_H_
-#define _ROUTED_H_
-#ifdef __cplusplus
-extern "C" {
-#endif
-#ident "$Revision: 1.4 $"
+#ifndef _PROTOCOLS_ROUTED_H_
+#define _PROTOCOLS_ROUTED_H_
/*
* Routing Information Protocol
@@ -47,93 +43,44 @@ extern "C" {
* by changing 32-bit net numbers to sockaddr's and
* padding stuff to 32-bit boundaries.
*/
+#define RIPVERSION 1
-#define RIPv1 1
-#define RIPv2 2
-#ifndef RIPVERSION
-#define RIPVERSION RIPv1
-#endif
-
-#define RIP_PORT 520
-
-#if RIPVERSION == 1
-/* Note that this so called sockaddr has a 2-byte sa_family and no sa_len.
- * It is not a UNIX sockaddr, but the shape of an address as defined
- * in RIPv1.
- */
struct netinfo {
struct sockaddr rip_dst; /* destination net/host */
int rip_metric; /* cost of route */
};
-#else
-struct netinfo {
- u_short n_family;
-#define RIP_AF_INET htons(AF_INET)
-#define RIP_AF_UNSPEC 0
-#define RIP_AF_AUTH 0xffff
- u_short n_tag; /* optional in RIPv2 */
- u_int n_dst; /* destination net or host */
-#define RIP_DEFAULT 0
- u_int n_mask; /* netmask in RIPv2 */
- u_int n_nhop; /* optional next hop in RIPv2 */
- u_int n_metric; /* cost of route */
-};
-#endif
-
-/* RIPv2 authentication */
-struct netauth {
- u_short a_type;
-#define RIP_AUTH_PW htons(2) /* password type */
- union {
-#define RIP_AUTH_PW_LEN 16
- char au_pw[RIP_AUTH_PW_LEN];
- } au;
-};
struct rip {
u_char rip_cmd; /* request/response */
u_char rip_vers; /* protocol version # */
- u_short rip_res1; /* pad to 32-bit boundary */
- union { /* variable length... */
- struct netinfo ru_nets[1];
- char ru_tracefile[1];
- struct netauth ru_auth[1];
+ u_char rip_res1[2]; /* pad to 32-bit boundary */
+ union {
+ struct netinfo ru_nets[1]; /* variable length... */
+ char ru_tracefile[1]; /* ditto ... */
} ripun;
#define rip_nets ripun.ru_nets
#define rip_tracefile ripun.ru_tracefile
};
-/* Packet types.
+/*
+ * Packet types.
*/
#define RIPCMD_REQUEST 1 /* want info */
#define RIPCMD_RESPONSE 2 /* responding to request */
#define RIPCMD_TRACEON 3 /* turn tracing on */
#define RIPCMD_TRACEOFF 4 /* turn it off */
-/* Gated extended RIP to include a "poll" command instead of using
- * RIPCMD_REQUEST with (RIP_AF_UNSPEC, RIP_DEFAULT). RFC 1058 says
- * command 5 is used by Sun Microsystems for its own purposes.
- */
-#define RIPCMD_POLL 5
-
-#define RIPCMD_MAX 6
-
+#define RIPCMD_MAX 5
#ifdef RIPCMDS
-char *ripcmds[RIPCMD_MAX] = {
- "#0", "REQUEST", "RESPONSE", "TRACEON", "TRACEOFF"
-};
+char *ripcmds[RIPCMD_MAX] =
+ { "#0", "REQUEST", "RESPONSE", "TRACEON", "TRACEOFF" };
#endif
-#define HOPCNT_INFINITY 16
+#define HOPCNT_INFINITY 16 /* per Xerox NS */
#define MAXPACKETSIZE 512 /* max broadcast size */
-#define NETS_LEN ((MAXPACKETSIZE-sizeof(struct rip)) \
- / sizeof(struct netinfo) +1)
-
-#define INADDR_RIP_GROUP (u_long)0xe0000009 /* 224.0.0.9 */
-
-/* Timer values used in managing the routing table.
- *
+/*
+ * Timer values used in managing the routing table.
* Complete tables are broadcast every SUPPLY_INTERVAL seconds.
* If changes occur between updates, dynamic updates containing only changes
* may be sent. When these are sent, a timer is set for a random value
@@ -142,30 +89,16 @@ char *ripcmds[RIPCMD_MAX] = {
*
* Every update of a routing entry forces an entry's timer to be reset.
* After EXPIRE_TIME without updates, the entry is marked invalid,
- * but held onto until GARBAGE_TIME so that others may see it, to
- * "poison" the bad route.
+ * but held onto until GARBAGE_TIME so that others may
+ * see it "be deleted".
*/
+#define TIMER_RATE 30 /* alarm clocks every 30 seconds */
+
#define SUPPLY_INTERVAL 30 /* time to supply tables */
-#define MIN_WAITTIME 2 /* min sec until next flash updates */
-#define MAX_WAITTIME 5 /* max sec until flash update */
+#define MIN_WAITTIME 2 /* min. interval to broadcast changes */
+#define MAX_WAITTIME 5 /* max. time to delay changes */
-#define STALE_TIME 90 /* switch to a new gateway */
#define EXPIRE_TIME 180 /* time to mark entry invalid */
#define GARBAGE_TIME 240 /* time to garbage collect */
-/* It is good to continue advertising bad routes this long so other
- * routers notice. This is fairly cheap, so it can be long. It
- * should be long to combat bogus holddowns implemented by major
- * router vendors.
- */
-#define POISON_TIME 120
-
-/* Do not switch to a new route for this long after a route has gone
- * bad, to ensure that the new route is not a remanent of the old route.
- */
-#define HOLD_TIME (MAX_WAITTIME*2)
-
-#ifdef __cplusplus
-}
-#endif
#endif /* !_ROUTED_H_ */
diff --git a/include/resolv.h b/include/resolv.h
index 77b4d1bff7e7..b7e24e7d02dc 100644
--- a/include/resolv.h
+++ b/include/resolv.h
@@ -53,7 +53,7 @@
*
* @(#)resolv.h 8.1 (Berkeley) 6/2/93
* From Id: resolv.h,v 4.9.1.2 1993/05/17 09:59:01 vixie Exp
- * $Id: resolv.h,v 1.6 1996/01/30 23:30:34 mpp Exp $
+ * $Id: resolv.h,v 1.3.4.1 1995/08/30 04:06:27 davidg Exp $
*/
#ifndef _RESOLV_H_
@@ -72,7 +72,7 @@
* is new enough to contain a certain feature.
*/
-#define __RES 19951031
+#define __RES 19950621
/*
* Resolver configuration file.
@@ -115,7 +115,6 @@ struct __res_state {
struct in_addr addr;
u_int32_t mask;
} sort_list[MAXRESOLVSORT];
- char pad[72]; /* On an i386 this means 512b total. */
};
/*
@@ -126,7 +125,7 @@ struct __res_state {
#define RES_AAONLY 0x00000004 /* authoritative answers only (!IMPL)*/
#define RES_USEVC 0x00000008 /* use virtual circuit */
#define RES_PRIMARY 0x00000010 /* query primary server only (!IMPL) */
-#define RES_IGNTC 0x00000020 /* ignore truncation errors */
+#define RES_IGNTC 0x00000020 /* ignore trucation errors */
#define RES_RECURSE 0x00000040 /* recursion desired */
#define RES_DEFNAMES 0x00000080 /* use default domain name */
#define RES_STAYOPEN 0x00000100 /* Keep TCP socket open */
diff --git a/include/rpc/auth.h b/include/rpc/auth.h
index 087e98805ae3..5ac0f61d0be1 100644
--- a/include/rpc/auth.h
+++ b/include/rpc/auth.h
@@ -7,7 +7,7 @@
* program developed by the user.
*
* SUN RPC IS PROVIDED AS IS WITH NO WARRANTIES OF ANY KIND INCLUDING THE
- * WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+ * WARRANTIES OF DESIGN, MERCHANTIBILITY AND FITNESS FOR A PARTICULAR
* PURPOSE, OR ARISING FROM A COURSE OF DEALING, USAGE OR TRADE PRACTICE.
*
* Sun RPC is provided with no support and without any obligation on the
@@ -28,7 +28,7 @@
*
* from: @(#)auth.h 1.17 88/02/08 SMI
* from: @(#)auth.h 2.3 88/08/07 4.0 RPCSRC
- * $Id: auth.h,v 1.5 1996/01/31 08:02:11 hsu Exp $
+ * $Id: auth.h,v 1.3 1995/05/30 04:55:09 rgrimes Exp $
*/
/*
@@ -68,10 +68,14 @@ enum auth_stat {
AUTH_FAILED=7 /* some unknown reason */
};
+#if (mc68000 || sparc || vax || i386 || tahoe || hp300)
+typedef u_long u_int32; /* 32-bit unsigned integers */
+#endif
+
union des_block {
struct {
- u_int32_t high;
- u_int32_t low;
+ u_int32 high;
+ u_int32 low;
} key;
char c[8];
};
@@ -100,7 +104,7 @@ typedef struct {
struct auth_ops {
void (*ah_nextverf)();
int (*ah_marshal)(); /* nextverf & serialize */
- int (*ah_validate)(); /* validate verifier */
+ int (*ah_validate)(); /* validate varifier */
int (*ah_refresh)(); /* refresh credentials */
void (*ah_destroy)(); /* destroy this structure */
} *ah_ops;
diff --git a/include/rpc/auth_unix.h b/include/rpc/auth_unix.h
index 34ddc1ad2edd..4699ada38f9e 100644
--- a/include/rpc/auth_unix.h
+++ b/include/rpc/auth_unix.h
@@ -7,7 +7,7 @@
* program developed by the user.
*
* SUN RPC IS PROVIDED AS IS WITH NO WARRANTIES OF ANY KIND INCLUDING THE
- * WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+ * WARRANTIES OF DESIGN, MERCHANTIBILITY AND FITNESS FOR A PARTICULAR
* PURPOSE, OR ARISING FROM A COURSE OF DEALING, USAGE OR TRADE PRACTICE.
*
* Sun RPC is provided with no support and without any obligation on the
@@ -28,7 +28,7 @@
*
* from: @(#)auth_unix.h 1.8 88/02/08 SMI
* from: @(#)auth_unix.h 2.2 88/07/29 4.0 RPCSRC
- * $Id: auth_unix.h,v 1.4 1996/01/30 23:31:42 mpp Exp $
+ * $Id: auth_unix.h,v 1.3 1995/05/30 04:55:11 rgrimes Exp $
*/
/*
diff --git a/include/rpc/clnt.h b/include/rpc/clnt.h
index 02080eb3e032..12b1f20d2854 100644
--- a/include/rpc/clnt.h
+++ b/include/rpc/clnt.h
@@ -7,7 +7,7 @@
* program developed by the user.
*
* SUN RPC IS PROVIDED AS IS WITH NO WARRANTIES OF ANY KIND INCLUDING THE
- * WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+ * WARRANTIES OF DESIGN, MERCHANTIBILITY AND FITNESS FOR A PARTICULAR
* PURPOSE, OR ARISING FROM A COURSE OF DEALING, USAGE OR TRADE PRACTICE.
*
* Sun RPC is provided with no support and without any obligation on the
@@ -28,7 +28,7 @@
*
* from: @(#)clnt.h 1.31 88/02/08 SMI
* from: @(#)clnt.h 2.1 88/07/29 4.0 RPCSRC
- * $Id: clnt.h,v 1.4 1996/01/30 23:31:48 mpp Exp $
+ * $Id: clnt.h,v 1.3 1995/05/30 04:55:14 rgrimes Exp $
*/
/*
@@ -91,7 +91,7 @@ enum clnt_stat {
struct rpc_err {
enum clnt_stat re_status;
union {
- int RE_errno; /* related system error */
+ int RE_errno; /* realated system error */
enum auth_stat RE_why; /* why the auth error occurred */
struct {
u_long low; /* lowest verion supported */
@@ -210,7 +210,7 @@ typedef struct {
/*
- * RPCTEST is a test program which is accessible on every rpc
+ * RPCTEST is a test program which is accessable on every rpc
* transport/port. It is used for testing, performance evaluation,
* and network administration.
*/
diff --git a/include/rpc/pmap_clnt.h b/include/rpc/pmap_clnt.h
index a0b53b4351ef..72c9c4398e45 100644
--- a/include/rpc/pmap_clnt.h
+++ b/include/rpc/pmap_clnt.h
@@ -7,7 +7,7 @@
* program developed by the user.
*
* SUN RPC IS PROVIDED AS IS WITH NO WARRANTIES OF ANY KIND INCLUDING THE
- * WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+ * WARRANTIES OF DESIGN, MERCHANTIBILITY AND FITNESS FOR A PARTICULAR
* PURPOSE, OR ARISING FROM A COURSE OF DEALING, USAGE OR TRADE PRACTICE.
*
* Sun RPC is provided with no support and without any obligation on the
@@ -28,7 +28,7 @@
*
* from: @(#)pmap_clnt.h 1.11 88/02/08 SMI
* from: @(#)pmap_clnt.h 2.1 88/07/29 4.0 RPCSRC
- * $Id: pmap_clnt.h,v 1.4 1996/01/30 23:31:59 mpp Exp $
+ * $Id: pmap_clnt.h,v 1.3 1995/05/30 04:55:16 rgrimes Exp $
*/
/*
diff --git a/include/rpc/pmap_prot.h b/include/rpc/pmap_prot.h
index f4f19673842e..7263a0fed84b 100644
--- a/include/rpc/pmap_prot.h
+++ b/include/rpc/pmap_prot.h
@@ -7,7 +7,7 @@
* program developed by the user.
*
* SUN RPC IS PROVIDED AS IS WITH NO WARRANTIES OF ANY KIND INCLUDING THE
- * WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+ * WARRANTIES OF DESIGN, MERCHANTIBILITY AND FITNESS FOR A PARTICULAR
* PURPOSE, OR ARISING FROM A COURSE OF DEALING, USAGE OR TRADE PRACTICE.
*
* Sun RPC is provided with no support and without any obligation on the
@@ -28,7 +28,7 @@
*
* from: @(#)pmap_prot.h 1.14 88/02/08 SMI
* from: @(#)pmap_prot.h 2.1 88/07/29 4.0 RPCSRC
- * $Id: pmap_prot.h,v 1.4 1996/01/30 23:32:08 mpp Exp $
+ * $Id: pmap_prot.h,v 1.3 1995/05/30 04:55:18 rgrimes Exp $
*/
/*
diff --git a/include/rpc/pmap_rmt.h b/include/rpc/pmap_rmt.h
index d76131e49a34..95d1f94f85cd 100644
--- a/include/rpc/pmap_rmt.h
+++ b/include/rpc/pmap_rmt.h
@@ -7,7 +7,7 @@
* program developed by the user.
*
* SUN RPC IS PROVIDED AS IS WITH NO WARRANTIES OF ANY KIND INCLUDING THE
- * WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+ * WARRANTIES OF DESIGN, MERCHANTIBILITY AND FITNESS FOR A PARTICULAR
* PURPOSE, OR ARISING FROM A COURSE OF DEALING, USAGE OR TRADE PRACTICE.
*
* Sun RPC is provided with no support and without any obligation on the
@@ -28,7 +28,7 @@
*
* from: @(#)pmap_rmt.h 1.2 88/02/08 SMI
* from: @(#)pmap_rmt.h 2.1 88/07/29 4.0 RPCSRC
- * $Id: pmap_rmt.h,v 1.4 1996/01/30 23:32:12 mpp Exp $
+ * $Id: pmap_rmt.h,v 1.3 1995/05/30 04:55:20 rgrimes Exp $
*/
/*
diff --git a/include/rpc/rpc.h b/include/rpc/rpc.h
index 66bab11811bc..9ec14a4bec34 100644
--- a/include/rpc/rpc.h
+++ b/include/rpc/rpc.h
@@ -7,7 +7,7 @@
* program developed by the user.
*
* SUN RPC IS PROVIDED AS IS WITH NO WARRANTIES OF ANY KIND INCLUDING THE
- * WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+ * WARRANTIES OF DESIGN, MERCHANTIBILITY AND FITNESS FOR A PARTICULAR
* PURPOSE, OR ARISING FROM A COURSE OF DEALING, USAGE OR TRADE PRACTICE.
*
* Sun RPC is provided with no support and without any obligation on the
@@ -28,7 +28,7 @@
*
* from: @(#)rpc.h 1.9 88/02/08 SMI
* from: @(#)rpc.h 2.4 89/07/11 4.0 RPCSRC
- * $Id: rpc.h,v 1.5 1996/01/30 23:32:20 mpp Exp $
+ * $Id: rpc.h,v 1.4 1995/05/30 04:55:23 rgrimes Exp $
*/
/*
diff --git a/include/rpc/rpc_msg.h b/include/rpc/rpc_msg.h
index ff77693158a1..0e8a74fc7d4b 100644
--- a/include/rpc/rpc_msg.h
+++ b/include/rpc/rpc_msg.h
@@ -7,7 +7,7 @@
* program developed by the user.
*
* SUN RPC IS PROVIDED AS IS WITH NO WARRANTIES OF ANY KIND INCLUDING THE
- * WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+ * WARRANTIES OF DESIGN, MERCHANTIBILITY AND FITNESS FOR A PARTICULAR
* PURPOSE, OR ARISING FROM A COURSE OF DEALING, USAGE OR TRADE PRACTICE.
*
* Sun RPC is provided with no support and without any obligation on the
@@ -28,7 +28,7 @@
*
* from: @(#)rpc_msg.h 1.7 86/07/16 SMI
* from: @(#)rpc_msg.h 2.1 88/07/29 4.0 RPCSRC
- * $Id: rpc_msg.h,v 1.5 1996/01/30 23:32:24 mpp Exp $
+ * $Id: rpc_msg.h,v 1.4 1995/05/30 04:55:25 rgrimes Exp $
*/
/*
diff --git a/include/rpc/svc.h b/include/rpc/svc.h
index 2be1a7e5bfee..c9872d4560e3 100644
--- a/include/rpc/svc.h
+++ b/include/rpc/svc.h
@@ -7,7 +7,7 @@
* program developed by the user.
*
* SUN RPC IS PROVIDED AS IS WITH NO WARRANTIES OF ANY KIND INCLUDING THE
- * WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+ * WARRANTIES OF DESIGN, MERCHANTIBILITY AND FITNESS FOR A PARTICULAR
* PURPOSE, OR ARISING FROM A COURSE OF DEALING, USAGE OR TRADE PRACTICE.
*
* Sun RPC is provided with no support and without any obligation on the
@@ -28,7 +28,7 @@
*
* from: @(#)svc.h 1.20 88/02/08 SMI
* from: @(#)svc.h 2.2 88/07/29 4.0 RPCSRC
- * $Id: svc.h,v 1.5 1996/01/30 23:32:29 mpp Exp $
+ * $Id: svc.h,v 1.4 1995/05/30 04:55:28 rgrimes Exp $
*/
/*
@@ -76,7 +76,7 @@ typedef struct {
int xp_sock;
u_short xp_port; /* associated port number */
struct xp_ops {
- bool_t (*xp_recv)(); /* receive incoming requests */
+ bool_t (*xp_recv)(); /* receive incomming requests */
enum xprt_stat (*xp_stat)(); /* get transport status */
bool_t (*xp_getargs)(); /* get arguments */
bool_t (*xp_reply)(); /* send reply */
diff --git a/include/rpc/svc_auth.h b/include/rpc/svc_auth.h
index 093e6a669169..360e93430170 100644
--- a/include/rpc/svc_auth.h
+++ b/include/rpc/svc_auth.h
@@ -7,7 +7,7 @@
* program developed by the user.
*
* SUN RPC IS PROVIDED AS IS WITH NO WARRANTIES OF ANY KIND INCLUDING THE
- * WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+ * WARRANTIES OF DESIGN, MERCHANTIBILITY AND FITNESS FOR A PARTICULAR
* PURPOSE, OR ARISING FROM A COURSE OF DEALING, USAGE OR TRADE PRACTICE.
*
* Sun RPC is provided with no support and without any obligation on the
@@ -28,7 +28,7 @@
*
* from: @(#)svc_auth.h 1.6 86/07/16 SMI
* from: @(#)svc_auth.h 2.1 88/07/29 4.0 RPCSRC
- * $Id: svc_auth.h,v 1.4 1996/01/30 23:32:36 mpp Exp $
+ * $Id: svc_auth.h,v 1.3 1995/05/30 04:55:32 rgrimes Exp $
*/
/*
diff --git a/include/rpc/types.h b/include/rpc/types.h
index 8dc34df6f06c..3cdaee3fcd00 100644
--- a/include/rpc/types.h
+++ b/include/rpc/types.h
@@ -7,7 +7,7 @@
* program developed by the user.
*
* SUN RPC IS PROVIDED AS IS WITH NO WARRANTIES OF ANY KIND INCLUDING THE
- * WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+ * WARRANTIES OF DESIGN, MERCHANTIBILITY AND FITNESS FOR A PARTICULAR
* PURPOSE, OR ARISING FROM A COURSE OF DEALING, USAGE OR TRADE PRACTICE.
*
* Sun RPC is provided with no support and without any obligation on the
@@ -28,7 +28,7 @@
*
* from: @(#)types.h 1.18 87/07/24 SMI
* from: @(#)types.h 2.3 88/08/15 4.0 RPCSRC
- * $Id: types.h,v 1.4 1996/01/30 23:32:39 mpp Exp $
+ * $Id: types.h,v 1.3 1995/05/30 04:55:35 rgrimes Exp $
*/
/*
diff --git a/include/rpc/xdr.h b/include/rpc/xdr.h
index 49dd3320c5f9..87075abbe8fe 100644
--- a/include/rpc/xdr.h
+++ b/include/rpc/xdr.h
@@ -7,7 +7,7 @@
* program developed by the user.
*
* SUN RPC IS PROVIDED AS IS WITH NO WARRANTIES OF ANY KIND INCLUDING THE
- * WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+ * WARRANTIES OF DESIGN, MERCHANTIBILITY AND FITNESS FOR A PARTICULAR
* PURPOSE, OR ARISING FROM A COURSE OF DEALING, USAGE OR TRADE PRACTICE.
*
* Sun RPC is provided with no support and without any obligation on the
@@ -28,7 +28,7 @@
*
* from: @(#)xdr.h 1.19 87/04/22 SMI
* from: @(#)xdr.h 2.2 88/07/29 4.0 RPCSRC
- * $Id: xdr.h,v 1.4 1996/01/30 23:32:45 mpp Exp $
+ * $Id: xdr.h,v 1.3 1995/05/30 04:55:38 rgrimes Exp $
*/
/*
@@ -103,8 +103,8 @@ typedef bool_t (*xdrproc_t)();
/*
* The XDR handle.
* Contains operation which is being applied to the stream,
- * an operations vector for the particular implementation (e.g. see xdr_mem.c),
- * and two private fields for the use of the particular implementation.
+ * an operations vector for the paticular implementation (e.g. see xdr_mem.c),
+ * and two private fields for the use of the particular impelementation.
*/
typedef struct {
enum xdr_op x_op; /* operation; fast additional param */
@@ -192,7 +192,7 @@ struct xdr_discrim {
};
/*
- * In-line routines for fast encode/decode of primitive data types.
+ * In-line routines for fast encode/decode of primitve data types.
* Caveat emptor: these use single memory cycles to get the
* data from the underlying buffer, and will fail to operate
* properly if the data is not aligned. The standard way to use these
diff --git a/include/rpcsvc/Makefile b/include/rpcsvc/Makefile
index 52c23de44f70..d9d24e22a20c 100644
--- a/include/rpcsvc/Makefile
+++ b/include/rpcsvc/Makefile
@@ -1,5 +1,5 @@
# from: @(#)Makefile 2.3 88/08/11 4.0 RPCSRC
-# $Id: Makefile,v 1.7 1995/08/15 20:06:50 joerg Exp $
+# $Id: Makefile,v 1.3.4.1 1995/08/30 07:24:54 davidg Exp $
.SUFFIXES: .x
diff --git a/include/rpcsvc/bootparam_prot.x b/include/rpcsvc/bootparam_prot.x
index 249ed8ab90af..a6d4f0ee022f 100644
--- a/include/rpcsvc/bootparam_prot.x
+++ b/include/rpcsvc/bootparam_prot.x
@@ -44,6 +44,8 @@
%#include <sys/param.h>
%#include <sys/syslimits.h>
%#include <sys/ucred.h>
+%#include <nfs/nfsv2.h>
+%#include <nfs/nfs.h>
#else
%#ifndef lint
%/*static char sccsid[] = "from: @(#)bootparam_prot.x 1.2 87/06/24 Copyr 1987 Sun Micro";*/
diff --git a/include/rpcsvc/yp.x b/include/rpcsvc/yp.x
index ce5bcf264f9b..7e3175e1d521 100644
--- a/include/rpcsvc/yp.x
+++ b/include/rpcsvc/yp.x
@@ -34,7 +34,7 @@
#ifndef RPC_HDR
%#ifndef lint
%/*static char sccsid[] = "from: @(#)yp.x 2.1 88/08/01 4.0 RPCSRC";*/
-%static char rcsid[] = "$Id: yp.x,v 1.5 1996/02/26 02:22:53 wpaul Exp $";
+%static char rcsid[] = "$Id: yp.x,v 1.1 1994/08/04 19:01:55 wollman Exp $";
%#endif /* not lint */
#endif
@@ -119,13 +119,8 @@ struct ypresp_val {
struct ypresp_key_val {
ypstat stat;
-#ifdef STUPID_SUN_BUG /* These are backwards */
keydat key;
valdat val;
-#else
- valdat val;
- keydat key;
-#endif
};
@@ -225,78 +220,9 @@ struct ypbind_setdom {
/*
- * NIS v1 support for backwards compatibility
- */
-enum ypreqtype {
- YPREQ_KEY = 1,
- YPREQ_NOKEY = 2,
- YPREQ_MAP_PARMS = 3
-};
-
-enum ypresptype {
- YPRESP_VAL = 1,
- YPRESP_KEY_VAL = 2,
- YPRESP_MAP_PARMS = 3
-};
-
-union yprequest switch (ypreqtype yp_reqtype) {
-case YPREQ_KEY:
- ypreq_key yp_req_keytype;
-case YPREQ_NOKEY:
- ypreq_nokey yp_req_nokeytype;
-case YPREQ_MAP_PARMS:
- ypmap_parms yp_req_map_parmstype;
-};
-
-union ypresponse switch (ypresptype yp_resptype) {
-case YPRESP_VAL:
- ypresp_val yp_resp_valtype;
-case YPRESP_KEY_VAL:
- ypresp_key_val yp_resp_key_valtype;
-case YPRESP_MAP_PARMS:
- ypmap_parms yp_resp_map_parmstype;
-};
-
-#if !defined(YPBIND_ONLY) && !defined(YPPUSH_ONLY)
-/*
* YP access protocol
*/
program YPPROG {
-/*
- * NIS v1 support for backwards compatibility
- */
- version YPOLDVERS {
- void
- YPOLDPROC_NULL(void) = 0;
-
- bool
- YPOLDPROC_DOMAIN(domainname) = 1;
-
- bool
- YPOLDPROC_DOMAIN_NONACK(domainname) = 2;
-
- ypresponse
- YPOLDPROC_MATCH(yprequest) = 3;
-
- ypresponse
- YPOLDPROC_FIRST(yprequest) = 4;
-
- ypresponse
- YPOLDPROC_NEXT(yprequest) = 5;
-
- ypresponse
- YPOLDPROC_POLL(yprequest) = 6;
-
- ypresponse
- YPOLDPROC_PUSH(yprequest) = 7;
-
- ypresponse
- YPOLDPROC_PULL(yprequest) = 8;
-
- ypresponse
- YPOLDPROC_GET(yprequest) = 9;
- } = 1;
-
version YPVERS {
void
YPPROC_NULL(void) = 0;
@@ -311,11 +237,8 @@ program YPPROG {
YPPROC_MATCH(ypreq_key) = 3;
ypresp_key_val
-#ifdef STUPID_SUN_BUG /* should be ypreq_nokey */
YPPROC_FIRST(ypreq_key) = 4;
-#else
- YPPROC_FIRST(ypreq_nokey) = 4;
-#endif
+
ypresp_key_val
YPPROC_NEXT(ypreq_key) = 5;
@@ -338,8 +261,8 @@ program YPPROG {
YPPROC_MAPLIST(domainname) = 11;
} = 2;
} = 100004;
-#endif
-#if !defined(YPSERV_ONLY) && !defined(YPBIND_ONLY)
+
+
/*
* YPPUSHPROC_XFRRESP is the callback routine for result of YPPROC_XFR
*/
@@ -347,17 +270,13 @@ program YPPUSH_XFRRESPPROG {
version YPPUSH_XFRRESPVERS {
void
YPPUSHPROC_NULL(void) = 0;
-#ifdef STUPID_SUN_BUG /* argument and return value are backwards */
+
yppushresp_xfr
YPPUSHPROC_XFRRESP(void) = 1;
-#else
- void
- YPPUSHPROC_XFRRESP(yppushresp_xfr) = 1;
-#endif
} = 1;
} = 0x40000000; /* transient: could be anything up to 0x5fffffff */
-#endif
-#if !defined(YPSERV_ONLY) && !defined(YPPUSH_ONLY)
+
+
/*
* YP binding protocol
*/
@@ -374,4 +293,4 @@ program YPBINDPROG {
} = 2;
} = 100007;
-#endif
+
diff --git a/include/rpcsvc/yp_prot.h b/include/rpcsvc/yp_prot.h
index 63df4d6c5a5b..7daf9a1402c7 100644
--- a/include/rpcsvc/yp_prot.h
+++ b/include/rpcsvc/yp_prot.h
@@ -26,7 +26,7 @@
* OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
* SUCH DAMAGE.
*
- * $Id: yp_prot.h,v 1.3 1996/01/30 23:33:04 mpp Exp $
+ * $Id: yp_prot.h,v 1.2 1995/05/30 04:55:47 rgrimes Exp $
*/
#ifndef _YP_PROT_H_
@@ -294,8 +294,8 @@ struct ypbind_setdom {
* is supplied to ypxfr as a command-line parameter when it
* is activated by ypserv."
*
- * This protocol is not implemented, naturally, because this YP
- * implementation only does the client side.
+ * This protocol is not implimented, naturally, because this YP
+ * implimentation only does the client side.
*/
#define YPPUSHVERS ((u_long)1)
#define YPPUSHVERS_ORIG ((u_long)1)
@@ -314,7 +314,7 @@ struct yppushresp_xfr {
#define YPPUSH_AGE ((long)2) /* Master's version not newer */
#define YPPUSH_NOMAP ((long)-1) /* Can't find server for map */
#define YPPUSH_NODOM ((long)-2) /* Domain not supported */
-#define YPPUSH_RSRC ((long)-3) /* Local resource alloc failure */
+#define YPPUSH_RSRC ((long)-3) /* Local resouce alloc failure */
#define YPPUSH_RPC ((long)-4) /* RPC failure talking to server */
#define YPPUSH_MADDR ((long)-5) /* Can't get master address */
#define YPPUSH_YPERR ((long)-6) /* YP server/map db error */
diff --git a/include/runetype.h b/include/runetype.h
index e7fdf5d74b11..4bce6588b8ba 100644
--- a/include/runetype.h
+++ b/include/runetype.h
@@ -39,22 +39,13 @@
#ifndef _RUNETYPE_H_
#define _RUNETYPE_H_
-#include <sys/cdefs.h>
#include <machine/ansi.h>
+#include <sys/cdefs.h>
-#ifdef _BSD_RUNE_T_
-typedef _BSD_RUNE_T_ rune_t;
-#undef _BSD_RUNE_T_
-#endif
-
-#ifdef _BSD_SIZE_T_
-typedef _BSD_SIZE_T_ size_t;
-#undef _BSD_SIZE_T_
-#endif
-
-#ifdef _BSD_WCHAR_T_
-typedef _BSD_WCHAR_T_ wchar_t;
-#undef _BSD_WCHAR_T_
+#ifdef _BSD_WCHAR_T_
+typedef _BSD_WCHAR_T_ rune_t;
+typedef _BSD_WCHAR_T_ wchar_t;
+#undef _BSD_WCHAR_T_
#endif
#define _CACHED_RUNES (1 <<8 ) /* Must be a power of 2 */
@@ -80,9 +71,9 @@ typedef struct {
char encoding[32]; /* ASCII name of this encoding */
rune_t (*sgetrune)
- __P((const char *, size_t, char const **));
+ __P((const char *, unsigned int, char const **));
int (*sputrune)
- __P((rune_t, char *, size_t, char **));
+ __P((rune_t, char *, unsigned int, char **));
rune_t invalid_rune;
unsigned long runetype[_CACHED_RUNES];
diff --git a/include/signal.h b/include/signal.h
index d8ebeeeeac08..6bb7ddf2cca4 100644
--- a/include/signal.h
+++ b/include/signal.h
@@ -33,12 +33,12 @@
* @(#)signal.h 8.3 (Berkeley) 3/30/94
*/
-#ifndef _SIGNAL_H_
-#define _SIGNAL_H_
+#ifndef _USER_SIGNAL_H
+#define _USER_SIGNAL_H
+#include <sys/types.h>
#include <sys/cdefs.h>
#include <sys/signal.h>
-#include <machine/ansi.h>
#if !defined(_ANSI_SOURCE) && !defined(_POSIX_SOURCE)
extern __const char *__const sys_signame[NSIG];
@@ -48,7 +48,7 @@ extern __const char *__const sys_siglist[NSIG];
__BEGIN_DECLS
int raise __P((int));
#ifndef _ANSI_SOURCE
-int kill __P((_BSD_PID_T_, int));
+int kill __P((pid_t, int));
int sigaction __P((int, const struct sigaction *, struct sigaction *));
int sigaddset __P((sigset_t *, int));
int sigdelset __P((sigset_t *, int));
@@ -59,7 +59,7 @@ int sigpending __P((sigset_t *));
int sigprocmask __P((int, const sigset_t *, sigset_t *));
int sigsuspend __P((const sigset_t *));
#ifndef _POSIX_SOURCE
-int killpg __P((_BSD_PID_T_, int));
+int killpg __P((pid_t, int));
int sigblock __P((int));
int siginterrupt __P((int, int));
int sigpause __P((int));
@@ -68,17 +68,15 @@ int sigsetmask __P((int));
int sigstack __P((const struct sigstack *, struct sigstack *));
int sigvec __P((int, struct sigvec *, struct sigvec *));
void psignal __P((unsigned int, const char *));
-#endif /* !_POSIX_SOURCE */
-#endif /* !_ANSI_SOURCE */
+#endif /* !_POSIX_SOURCE */
+#endif /* !_ANSI_SOURCE */
__END_DECLS
-#ifndef _ANSI_SOURCE
/* List definitions after function declarations, or Reiser cpp gets upset. */
#define sigaddset(set, signo) (*(set) |= 1 << ((signo) - 1), 0)
#define sigdelset(set, signo) (*(set) &= ~(1 << ((signo) - 1)), 0)
#define sigemptyset(set) (*(set) = 0, 0)
#define sigfillset(set) (*(set) = ~(sigset_t)0, 0)
#define sigismember(set, signo) ((*(set) & (1 << ((signo) - 1))) != 0)
-#endif /* !_ANSI_SOURCE */
-#endif /* !_SIGNAL_H_ */
+#endif /* !_USER_SIGNAL_H */
diff --git a/include/stddef.h b/include/stddef.h
index 38a773636a78..70af6892224a 100644
--- a/include/stddef.h
+++ b/include/stddef.h
@@ -40,19 +40,15 @@
typedef _BSD_PTRDIFF_T_ ptrdiff_t;
-#if !defined(_ANSI_SOURCE) && !defined(_POSIX_SOURCE)
-#ifdef _BSD_RUNE_T_
-typedef _BSD_RUNE_T_ rune_t;
-#undef _BSD_RUNE_T_
-#endif
-#endif
-
#ifdef _BSD_SIZE_T_
typedef _BSD_SIZE_T_ size_t;
#undef _BSD_SIZE_T_
#endif
#ifdef _BSD_WCHAR_T_
+#ifndef _ANSI_SOURCE
+typedef _BSD_WCHAR_T_ rune_t;
+#endif
typedef _BSD_WCHAR_T_ wchar_t;
#undef _BSD_WCHAR_T_
#endif
diff --git a/include/stdio.h b/include/stdio.h
index 9c4c37ee49e7..595f8f27dc1b 100644
--- a/include/stdio.h
+++ b/include/stdio.h
@@ -162,8 +162,8 @@ __END_DECLS
#define __SMBF 0x0080 /* _buf is from malloc */
#define __SAPP 0x0100 /* fdopen()ed in append mode */
#define __SSTR 0x0200 /* this is an sprintf/snprintf string */
-#define __SOPT 0x0400 /* do fseek() optimization */
-#define __SNPT 0x0800 /* do not do fseek() optimization */
+#define __SOPT 0x0400 /* do fseek() optimisation */
+#define __SNPT 0x0800 /* do not do fseek() optimisation */
#define __SOFF 0x1000 /* set iff _offset is in fact correct */
#define __SMOD 0x2000 /* true => fgetln modified _p text */
@@ -224,7 +224,7 @@ int ferror __P((FILE *));
int fflush __P((FILE *));
int fgetc __P((FILE *));
int fgetpos __P((FILE *, fpos_t *));
-char *fgets __P((char *, int, FILE *));
+char *fgets __P((char *, size_t, FILE *));
FILE *fopen __P((const char *, const char *));
int fprintf __P((FILE *, const char *, ...));
int fputc __P((int, FILE *));
@@ -234,7 +234,7 @@ FILE *freopen __P((const char *, const char *, FILE *));
int fscanf __P((FILE *, const char *, ...));
int fseek __P((FILE *, long, int));
int fsetpos __P((FILE *, const fpos_t *));
-long ftell __P((FILE *));
+long ftell __P((const FILE *));
size_t fwrite __P((const void *, size_t, size_t, FILE *));
int getc __P((FILE *));
int getchar __P((void));
@@ -283,7 +283,6 @@ __END_DECLS
*/
#if !defined (_ANSI_SOURCE) && !defined(_POSIX_SOURCE)
__BEGIN_DECLS
-int asprintf __P((char **, const char *, ...));
char *fgetln __P((FILE *, size_t *));
int fpurge __P((FILE *));
int getw __P((FILE *));
@@ -294,7 +293,6 @@ void setbuffer __P((FILE *, char *, int));
int setlinebuf __P((FILE *));
char *tempnam __P((const char *, const char *));
int snprintf __P((char *, size_t, const char *, ...));
-int vasprintf __P((char **, const char *, _BSD_VA_LIST_));
int vsnprintf __P((char *, size_t, const char *, _BSD_VA_LIST_));
int vscanf __P((const char *, _BSD_VA_LIST_));
int vsscanf __P((const char *, const char *, _BSD_VA_LIST_));
diff --git a/include/stdlib.h b/include/stdlib.h
index 069656d4719b..3f1d64895595 100644
--- a/include/stdlib.h
+++ b/include/stdlib.h
@@ -38,19 +38,15 @@
#include <machine/ansi.h>
-#if !defined(_ANSI_SOURCE) && !defined(_POSIX_SOURCE)
-#ifdef _BSD_RUNE_T_
-typedef _BSD_RUNE_T_ rune_t;
-#undef _BSD_RUNE_T_
-#endif
-#endif
-
#ifdef _BSD_SIZE_T_
typedef _BSD_SIZE_T_ size_t;
#undef _BSD_SIZE_T_
#endif
#ifdef _BSD_WCHAR_T_
+#if !defined(_ANSI_SOURCE) && !defined(_POSIX_SOURCE)
+typedef _BSD_WCHAR_T_ rune_t;
+#endif
typedef _BSD_WCHAR_T_ wchar_t;
#undef _BSD_WCHAR_T_
#endif
diff --git a/include/strhash.h b/include/strhash.h
index 7533fb9c7711..59523da9cf79 100644
--- a/include/strhash.h
+++ b/include/strhash.h
@@ -1,7 +1,7 @@
#ifndef _STRHASH_H_INCLUDE
#define _STRHASH_H_INCLUDE
-/* $Header: /home/ncvs/src/include/strhash.h,v 1.1 1995/03/26 10:12:53 jkh Exp $ */
+/* $Header: /pub/FreeBSD/FreeBSD-CVS/src/include/strhash.h,v 1.2 1995/05/30 04:54:49 rgrimes Exp $ */
/*
*
diff --git a/include/time.h b/include/time.h
index 0c119a3c3ede..884a2fb9bfd6 100644
--- a/include/time.h
+++ b/include/time.h
@@ -100,13 +100,6 @@ time_t mktime __P((struct tm *));
size_t strftime __P((char *, size_t, const char *, const struct tm *));
time_t time __P((time_t *));
-#ifdef _THREAD_SAFE
-int asctime_r __P((const struct tm *, char *, int));
-int ctime_r __P((const time_t *, char *, int));
-int gmtime_r __P((const time_t *, struct tm *));
-int localtime_r __P((const time_t *, struct tm *));
-#endif
-
#ifndef _ANSI_SOURCE
void tzset __P((void));
#endif /* not ANSI */
diff --git a/include/unistd.h b/include/unistd.h
index 94df71e4b1d6..eb6d141aba6f 100644
--- a/include/unistd.h
+++ b/include/unistd.h
@@ -142,7 +142,6 @@ int re_exec __P((const char *));
int readlink __P((const char *, char *, int));
int reboot __P((int));
int revoke __P((const char *));
-pid_t rfork __P((int));
int rresvport __P((int *));
int ruserok __P((const char *, int, const char *, const char *));
char *sbrk __P((int));
@@ -166,7 +165,6 @@ int swapon __P((const char *));
int symlink __P((const char *, const char *));
void sync __P((void));
int syscall __P((int, ...));
-off_t __syscall __P((quad_t, ...));
int truncate __P((const char *, off_t));
int ttyslot __P((void));
unsigned int ualarm __P((unsigned int, unsigned int));
diff --git a/include/vis.h b/include/vis.h
index a172afc8662f..53ef1a91c4b9 100644
--- a/include/vis.h
+++ b/include/vis.h
@@ -31,24 +31,16 @@
* SUCH DAMAGE.
*
* @(#)vis.h 8.1 (Berkeley) 6/2/93
- * $Id: vis.h,v 1.3 1996/05/01 00:57:57 bde Exp $
*/
#ifndef _VIS_H_
#define _VIS_H_
-#include <machine/ansi.h>
-
-#ifdef _BSD_SIZE_T_
-typedef _BSD_SIZE_T_ size_t;
-#undef _BSD_SIZE_T_
-#endif
-
/*
* to select alternate encoding format
*/
#define VIS_OCTAL 0x01 /* use octal \ddd format */
-#define VIS_CSTYLE 0x02 /* use \[nrft0..] where appropriate */
+#define VIS_CSTYLE 0x02 /* use \[nrft0..] where appropiate */
/*
* to alter set of characters encoded (default is to encode all
diff --git a/include/ctype.h b/include/ctype.h
index e14e514dd51c..157134eea879 100644
--- a/include/ctype.h
+++ b/include/ctype.h
@@ -111,16 +111,16 @@ __END_DECLS
#define ishexnumber(c) __istype((c), _X)
#define isideogram(c) __istype((c), _I)
#define isnumber(c) __istype((c), _D)
-#define isphonogram(c) __istype((c), _Q)
+#define isphonogram(c) __istype((c), _T)
#define isrune(c) __istype((c), 0xFFFFFF00L)
-#define isspecial(c) __istype((c), _T)
+#define isspecial(c) __istype((c), _Q)
#endif
/* See comments in <machine/ansi.h> about _BSD_CT_RUNE_T_. */
__BEGIN_DECLS
-unsigned long ___runetype __P((_BSD_CT_RUNE_T_));
-_BSD_CT_RUNE_T_ ___tolower __P((_BSD_CT_RUNE_T_));
-_BSD_CT_RUNE_T_ ___toupper __P((_BSD_CT_RUNE_T_));
+unsigned long ___runetype __P((_BSD_RUNE_T_));
+_BSD_RUNE_T_ ___tolower __P((_BSD_RUNE_T_));
+_BSD_RUNE_T_ ___toupper __P((_BSD_RUNE_T_));
__END_DECLS
/*
@@ -139,40 +139,48 @@ __END_DECLS
#if !defined(_DONT_USE_CTYPE_INLINE_) && \
(defined(_USE_CTYPE_INLINE_) || defined(__GNUC__) || defined(__cplusplus))
static __inline int
-__istype(_BSD_CT_RUNE_T_ _c, unsigned long _f)
+__istype(_BSD_RUNE_T_ _c, unsigned long _f)
{
- return (_c < 0 || _c >= _CACHED_RUNES) ? !!(___runetype(_c) & _f) :
- !!(_CurrentRuneLocale->runetype[_c] & _f);
+ if (_c < 0)
+ _c = (unsigned char) _c;
+ return((((_c & _CRMASK) ? ___runetype(_c) :
+ _CurrentRuneLocale->runetype[_c]) & _f) ? 1 : 0);
}
static __inline int
-__isctype(_BSD_CT_RUNE_T_ _c, unsigned long _f)
+__isctype(_BSD_RUNE_T_ _c, unsigned long _f)
{
- return (_c < 0 || _c >= _CACHED_RUNES) ? 0 :
- !!(_DefaultRuneLocale.runetype[_c] & _f);
+ if (_c < 0)
+ _c = (unsigned char) _c;
+ return((((_c & _CRMASK) ? 0 :
+ _DefaultRuneLocale.runetype[_c]) & _f) ? 1 : 0);
}
-static __inline _BSD_CT_RUNE_T_
-__toupper(_BSD_CT_RUNE_T_ _c)
+static __inline _BSD_RUNE_T_
+__toupper(_BSD_RUNE_T_ _c)
{
- return (_c < 0 || _c >= _CACHED_RUNES) ? ___toupper(_c) :
- _CurrentRuneLocale->mapupper[_c];
+ if (_c < 0)
+ _c = (unsigned char) _c;
+ return((_c & _CRMASK) ?
+ ___toupper(_c) : _CurrentRuneLocale->mapupper[_c]);
}
-static __inline _BSD_CT_RUNE_T_
-__tolower(_BSD_CT_RUNE_T_ _c)
+static __inline _BSD_RUNE_T_
+__tolower(_BSD_RUNE_T_ _c)
{
- return (_c < 0 || _c >= _CACHED_RUNES) ? ___tolower(_c) :
- _CurrentRuneLocale->maplower[_c];
+ if (_c < 0)
+ _c = (unsigned char) _c;
+ return((_c & _CRMASK) ?
+ ___tolower(_c) : _CurrentRuneLocale->maplower[_c]);
}
#else /* not using inlines */
__BEGIN_DECLS
-int __istype __P((_BSD_CT_RUNE_T_, unsigned long));
-int __isctype __P((_BSD_CT_RUNE_T_, unsigned long));
-_BSD_CT_RUNE_T_ __toupper __P((_BSD_CT_RUNE_T_));
-_BSD_CT_RUNE_T_ __tolower __P((_BSD_CT_RUNE_T_));
+int __istype __P((_BSD_RUNE_T_, unsigned long));
+int __isctype __P((_BSD_RUNE_T_, unsigned long));
+_BSD_RUNE_T_ __toupper __P((_BSD_RUNE_T_));
+_BSD_RUNE_T_ __tolower __P((_BSD_RUNE_T_));
__END_DECLS
#endif /* using inlines */
@@ -111,16 +111,16 @@ __END_DECLS
#endif
-/* See comments in <machine/ansi.h> about _BSD_CT_RUNE_T_. */
+/* See comments in <machine/ansi.h> about _BSD_RUNE_T_. */
__BEGIN_DECLS
diff --git a/include/mpool.h b/include/mpool.h
index 9e3ebeb4ed7a..17efb3f82cfc 100644
--- a/include/mpool.h
+++ b/include/mpool.h
@@ -1,5 +1,5 @@
/*-
- * Copyright (c) 1991, 1993, 1994
+ * Copyright (c) 1991, 1993
* The Regents of the University of California. All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
@@ -30,65 +30,101 @@
* OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
* SUCH DAMAGE.
*
- * @(#)mpool.h 8.2 (Berkeley) 7/14/94
+ * @(#)mpool.h 8.1 (Berkeley) 6/2/93
*/
#ifndef _MPOOL_H_
#define _MPOOL_H_
-#include <sys/queue.h>
-
/*
- * The memory pool scheme is a simple one. Each in-memory page is referenced
- * by a bucket which is threaded in up to two of three ways. All active pages
- * are threaded on a hash chain (hashed by page number) and an lru chain.
- * Inactive pages are threaded on a free chain. Each reference to a memory
- * pool is handed an opaque MPOOL cookie which stores all of this information.
+ * The memory pool scheme is a simple one. Each in memory page is referenced
+ * by a bucket which is threaded in three ways. All active pages are threaded
+ * on a hash chain (hashed by the page number) and an lru chain. Inactive
+ * pages are threaded on a free chain. Each reference to a memory pool is
+ * handed an MPOOL which is the opaque cookie passed to all of the memory
+ * routines.
*/
#define HASHSIZE 128
#define HASHKEY(pgno) ((pgno - 1) % HASHSIZE)
-/* The BKT structures are the elements of the queues. */
-typedef struct _bkt {
- CIRCLEQ_ENTRY(_bkt) hq; /* hash queue */
- CIRCLEQ_ENTRY(_bkt) q; /* lru queue */
- void *page; /* page */
- pgno_t pgno; /* page number */
+/* The BKT structures are the elements of the lists. */
+typedef struct BKT {
+ struct BKT *hnext; /* next hash bucket */
+ struct BKT *hprev; /* previous hash bucket */
+ struct BKT *cnext; /* next free/lru bucket */
+ struct BKT *cprev; /* previous free/lru bucket */
+ void *page; /* page */
+ pgno_t pgno; /* page number */
#define MPOOL_DIRTY 0x01 /* page needs to be written */
#define MPOOL_PINNED 0x02 /* page is pinned into memory */
- u_int8_t flags; /* flags */
+ unsigned long flags; /* flags */
} BKT;
+/* The BKTHDR structures are the heads of the lists. */
+typedef struct BKTHDR {
+ struct BKT *hnext; /* next hash bucket */
+ struct BKT *hprev; /* previous hash bucket */
+ struct BKT *cnext; /* next free/lru bucket */
+ struct BKT *cprev; /* previous free/lru bucket */
+} BKTHDR;
+
typedef struct MPOOL {
- CIRCLEQ_HEAD(_lqh, _bkt) lqh; /* lru queue head */
- /* hash queue array */
- CIRCLEQ_HEAD(_hqh, _bkt) hqh[HASHSIZE];
- pgno_t curcache; /* current number of cached pages */
- pgno_t maxcache; /* max number of cached pages */
- pgno_t npages; /* number of pages in the file */
- u_long pagesize; /* file page size */
- int fd; /* file descriptor */
- /* page in conversion routine */
+ BKTHDR free; /* The free list. */
+ BKTHDR lru; /* The LRU list. */
+ BKTHDR hashtable[HASHSIZE]; /* Hashed list by page number. */
+ pgno_t curcache; /* Current number of cached pages. */
+ pgno_t maxcache; /* Max number of cached pages. */
+ pgno_t npages; /* Number of pages in the file. */
+ u_long pagesize; /* File page size. */
+ int fd; /* File descriptor. */
+ /* Page in conversion routine. */
void (*pgin) __P((void *, pgno_t, void *));
- /* page out conversion routine */
+ /* Page out conversion routine. */
void (*pgout) __P((void *, pgno_t, void *));
- void *pgcookie; /* cookie for page in/out routines */
+ void *pgcookie; /* Cookie for page in/out routines. */
#ifdef STATISTICS
- u_long cachehit;
- u_long cachemiss;
- u_long pagealloc;
- u_long pageflush;
- u_long pageget;
- u_long pagenew;
- u_long pageput;
- u_long pageread;
- u_long pagewrite;
+ unsigned long cachehit;
+ unsigned long cachemiss;
+ unsigned long pagealloc;
+ unsigned long pageflush;
+ unsigned long pageget;
+ unsigned long pagenew;
+ unsigned long pageput;
+ unsigned long pageread;
+ unsigned long pagewrite;
#endif
} MPOOL;
+#ifdef __MPOOLINTERFACE_PRIVATE
+/* Macros to insert/delete into/from hash chain. */
+#define rmhash(bp) { \
+ (bp)->hprev->hnext = (bp)->hnext; \
+ (bp)->hnext->hprev = (bp)->hprev; \
+}
+#define inshash(bp, pg) { \
+ hp = &mp->hashtable[HASHKEY(pg)]; \
+ (bp)->hnext = hp->hnext; \
+ (bp)->hprev = (struct BKT *)hp; \
+ hp->hnext->hprev = (bp); \
+ hp->hnext = (bp); \
+}
+
+/* Macros to insert/delete into/from lru and free chains. */
+#define rmchain(bp) { \
+ (bp)->cprev->cnext = (bp)->cnext; \
+ (bp)->cnext->cprev = (bp)->cprev; \
+}
+#define inschain(bp, dp) { \
+ (bp)->cnext = (dp)->cnext; \
+ (bp)->cprev = (struct BKT *)(dp); \
+ (dp)->cnext->cprev = (bp); \
+ (dp)->cnext = (bp); \
+}
+#endif
+
__BEGIN_DECLS
-MPOOL *mpool_open __P((void *, int, pgno_t, pgno_t));
+MPOOL *mpool_open __P((DBT *, int, pgno_t, pgno_t));
void mpool_filter __P((MPOOL *, void (*)(void *, pgno_t, void *),
void (*)(void *, pgno_t, void *), void *));
void *mpool_new __P((MPOOL *, pgno_t *));